@@ -1,3 +1,4 @@
+import hashlib
 import re
 from copy import deepcopy
 
@@ -36,6 +37,15 @@ class Field(MetricsLayerBase, SQLReplacement):
         self.validate(definition)
         super().__init__(definition)
 
+    def __hash__(self) -> int:
+        result = hashlib.md5(self.id(view_only=True).encode("utf-8"))
+        return int(result.hexdigest(), base=16)
+
+    def __eq__(self, other):
+        if isinstance(other, str):
+            return False
+        return self.id(view_only=True) == other.id(view_only=True)
+
     def id(self, view_only=False, capitalize_alias=False):
         alias = self.alias()
         if capitalize_alias:
@@ -145,6 +155,22 @@ class Field(MetricsLayerBase, SQLReplacement):
         }
         return type_lookup[self.type](sql, query_type, functional_pk, alias_only)
 
+    def strict_replaced_query(self):
+        clean_sql = deepcopy(self.sql)
+        fields_to_replace = self.fields_to_replace(clean_sql)
+        for to_replace in fields_to_replace:
+            if to_replace == "TABLE":
+                clean_sql = clean_sql.replace("${TABLE}.", "")
+            else:
+                field = self.get_field_with_view_info(to_replace, ignore_explore=True)
+                if field:
+                    sql_replace = field.alias(with_view=True)
+                else:
+                    sql_replace = to_replace
+
+                clean_sql = clean_sql.replace("${" + to_replace + "}", sql_replace)
+        return clean_sql.strip()
+
     def _needs_symmetric_aggregate(self, functional_pk: MetricsLayerBase):
         if functional_pk:
             if functional_pk == Definitions.does_not_exist:
@@ -177,7 +203,7 @@ class Field(MetricsLayerBase, SQLReplacement):
         alias_only: bool = False,
         factor: int = 1_000_000,
     ):
-        if query_type == Definitions.snowflake:
+        if query_type in {Definitions.snowflake, Definitions.redshift}:
             return self._sum_symmetric_aggregate_snowflake(sql, primary_key_sql, alias_only, factor)
         elif query_type == Definitions.bigquery:
             return self._sum_symmetric_aggregate_bigquery(sql, primary_key_sql, alias_only, factor)
@@ -395,6 +421,8 @@ class Field(MetricsLayerBase, SQLReplacement):
                 "years": lambda start, end: f"DATE_DIFF(CAST({end} as DATE), CAST({start} as DATE), ISOYEAR)",
             },
         }
+        # Snowflake and redshift have identical syntax in this case
+        meta_lookup[Definitions.redshift] = meta_lookup[Definitions.snowflake]
         try:
             return meta_lookup[query_type][self.dimension_group](sql_start, sql_end)
         except KeyError:
@@ -430,6 +458,8 @@ class Field(MetricsLayerBase, SQLReplacement):
                 "day_of_week": lambda s, qt: f"CAST({s} AS STRING FORMAT 'DAY')",
             },
         }
+        # Snowflake and redshift have identical syntax in this case
+        meta_lookup[Definitions.redshift] = meta_lookup[Definitions.snowflake]
 
         return meta_lookup[query_type][self.dimension_group](sql, query_type)
 
@@ -454,7 +484,7 @@ class Field(MetricsLayerBase, SQLReplacement):
 
     @staticmethod
     def _week_sql_date_trunc(sql, offset, query_type):
-        if Definitions.snowflake == query_type:
+        if query_type in {Definitions.snowflake, Definitions.redshift}:
             if offset is None:
                 offset_sql = sql
             else:
@@ -466,7 +496,20 @@ class Field(MetricsLayerBase, SQLReplacement):
             return f"DATE_TRUNC(CAST({sql} as DATE) + {offset}, WEEK)"
 
     def collect_errors(self):
-        return []
+        errors = []
+        if not self.valid_name(self.name):
+            errors.append(self.name_error("field", self.name))
+        if self.type == "time" and "intervals" in self._definition:
+            errors.append(
+                f"Field {self.name} is of type time, but has property "
+                "intervals when it should have property timeframes"
+            )
+        if self.type == "duration" and "timeframes" in self._definition:
+            errors.append(
+                f"Field {self.name} is of type duration, but has property "
+                "timeframes when it should have property intervals"
+            )
+        return errors
 
     def get_referenced_sql_query(self, strings_only=True):
         if self.sql and ("{%" in self.sql or self.sql == ""):
@@ -484,12 +527,12 @@ class Field(MetricsLayerBase, SQLReplacement):
             return list(set(f"{f.view.name}.{f.name}" for f in valid_references))
         return referenced_fields
 
-    def referenced_fields(self, sql):
+    def referenced_fields(self, sql, ignore_explore: bool = False):
         reference_fields = []
         for to_replace in self.fields_to_replace(sql):
             if to_replace != "TABLE":
                 try:
-                    field = self.get_field_with_view_info(to_replace)
+                    field = self.get_field_with_view_info(to_replace, ignore_explore=ignore_explore)
                 except Exception:
                     field = None
                 to_replace_type = None if field is None else field.type
@@ -545,8 +588,8 @@ class Field(MetricsLayerBase, SQLReplacement):
                 clean_sql = clean_sql.replace("${" + to_replace + "}", sql_replace)
         return clean_sql.strip()
 
-    def get_field_with_view_info(self, field: str, specified_view: str = None):
-        _, view_name, field_name = self.field_name_parts(field)
+    def get_field_with_view_info(self, field: str, specified_view: str = None, ignore_explore: bool = False):
+        specified_explore, view_name, field_name = self.field_name_parts(field)
         if view_name is None and specified_view is None:
             view_name = self.view.name
         elif view_name is None and specified_view:
@@ -554,10 +597,10 @@ class Field(MetricsLayerBase, SQLReplacement):
 
         if self.view is None:
             raise AttributeError(f"You must specify which view this field is in '{self.name}'")
-        if self.view.explore:
+        if self.view.explore and not ignore_explore:
             explore_name = self.view.explore.name
         else:
-            explore_name = None
+            explore_name = specified_explore
         return self.view.project.get_field(field_name, view_name=view_name, explore_name=explore_name)
 
     def _translate_looker_tier_to_sql(self, sql: str, tiers: list):
