@@ -59,7 +59,7 @@ class MetricsLayerDesign:
         for join in joins_needed:
             for view_name in join.required_views():
                 self._join_graph.add_edge(view_name, join.from_, relationship=join.relationship)
-        self._ordered_join_names = list(networkx.bfs_tree(self._join_graph, source=self.base_view_name))
+        self._ordered_join_names = list(networkx.dfs_tree(self._join_graph, source=self.base_view_name))
         # Skip the first one because that's *always* the base of the explore
         return [self.explore.get_join(name, by_view_name=True) for name in self._ordered_join_names[1:]]
 
@@ -172,8 +172,8 @@ class MetricsLayerDesign:
     def get_join(self, name: str) -> MetricsLayerBase:
         return next((j for j in self.joins() if j.name == name), None)
 
-    def get_field(self, field_name: str, view_name: str = None) -> MetricsLayerBase:
-        return self.project.get_field(field_name, view_name=view_name, explore_name=self.explore.name)
+    def get_field(self, field_name: str) -> MetricsLayerBase:
+        return self.project.get_field(field_name, explore_name=self.explore.name)
 
     def get_access_filter(self):
         if self.explore.access_filters:
