@@ -7,6 +7,7 @@ from pypika import Criterion, JoinType, Order, Table
 from pypika.terms import LiteralValue
 
 from metrics_layer.core.model.base import MetricsLayerBase
+from metrics_layer.core.model.definitions import Definitions
 from metrics_layer.core.model.field import Field
 from metrics_layer.core.model.join import Join
 from metrics_layer.core.model.view import View
@@ -71,6 +72,8 @@ class MetricsLayerQuery(MetricsLayerBase):
 
         if order_by:
             self.order_by_args.extend(self._parse_order_by_object(order_by))
+        elif self.query_type in {Definitions.snowflake, Definitions.redshift}:
+            self.order_by_args.append({"field": "__DEFAULT__"})
 
     def _parse_filter_object(
         self, filter_object, filter_type: str, always_where: str = None, access_filter: str = None
@@ -160,10 +163,20 @@ class MetricsLayerQuery(MetricsLayerBase):
         # Handle order by
         if self.order_by_args and not self.no_group_by:
             for arg in self.order_by_args:
+                # If the order isn't specified, then we default to the first measure or dim if no measure
+                if arg["field"] == "__DEFAULT__":
+                    all_fields = self.metrics + self.dimensions
+                    first_field = self.design.get_field(all_fields[0])
+                    arg["sort"] = "desc" if first_field.field_type == "measure" else "asc"
+                    arg["field"] = first_field.alias(with_view=True)
                 order = Order.desc if arg["sort"] == "desc" else Order.asc
                 base_query = base_query.orderby(LiteralValue(arg["field"]), order=order)
 
-        sql = str(base_query.limit(self.limit))
+        completed_query = base_query.limit(self.limit)
+        if self.return_pypika_query:
+            return completed_query
+
+        sql = str(completed_query)
         if semicolon:
             sql += ";"
         return sql
